@@ -21,7 +21,12 @@ defaults to C<any> on Linux and dies on Windows.
 
 my $VERBOSE = 0;
 
-my $device = $^O =~ /MSWin32|cygwin/ ? qr/$ARGV[0]/i : $ARGV[0];
+my $device = $ARGV[0];
+
+
+if ($^O =~ /MSWin32|cygwin/ && $device) {
+ $device = qr/$device/i
+};
 
 my $sniffer = Sniffer::HTTP->new(
   callbacks => {
@@ -30,4 +35,4 @@ my $sniffer = Sniffer::HTTP->new(
       log      => sub { print $_[0] if $VERBOSE },
       tcp_log  => sub { print $_[0] if $VERBOSE > 1 },
   }
-)->run( $device, $ARGV[1] );
+)->run( $device, $ARGV[1] );
\ No newline at end of file
